==> smartgwtee-eval-5.1p.zip: com/smartgwt/client/docs/Validation.java <==

package com.smartgwt.client.docs;

/**
 * Validation
 * @see com.smartgwt.client.types.CharacterCasing
 * @see com.smartgwt.client.widgets.form.DynamicForm#validateData
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorsHTML
 * @see com.smartgwt.client.widgets.form.DynamicForm#getItemErrorHTML
 * @see com.smartgwt.client.widgets.form.DynamicForm#validate
 * @see com.smartgwt.client.widgets.form.DynamicForm#valuesAreValid
 * @see com.smartgwt.client.widgets.form.DynamicForm#checkForValidationErrors
 * @see com.smartgwt.client.widgets.grid.ListGrid#clearRowErrors
 * @see com.smartgwt.client.widgets.form.validator.Validator#addValidator
 * @see com.smartgwt.client.widgets.form.validator.Validator#addValidators
 * @see com.smartgwt.client.widgets.form.validator.Validator#addValidatorDefinition
 * @see com.smartgwt.client.widgets.form.validator.Validator#addValidatorDefinitions
 * @see com.smartgwt.client.data.DataSource#getUseLocalValidators
 * @see com.smartgwt.client.data.DataSourceField#getValidators
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowInlineErrors
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowErrorIcons
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowErrorText
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowErrorStyle
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorOrientation
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorItemProperties
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorItemCellStyle
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorsPreamble
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowTitlesWithErrorMessages
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrors
 * @see com.smartgwt.client.widgets.form.DynamicForm#getValidateOnChange
 * @see com.smartgwt.client.widgets.form.DynamicForm#getUnknownErrorMessage
 * @see com.smartgwt.client.widgets.form.DynamicForm#getNoErrorDetailsMessage
 * @see com.smartgwt.client.widgets.form.DynamicForm#getValidationURL
 * @see com.smartgwt.client.widgets.form.DynamicForm#getDisableValidation
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getRequired
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getRequiredMessage
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowErrorIcon
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowErrorText
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowErrorStyle
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getErrorOrientation
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getErrorMessageWidth
 * @see com.smartgwt.client.widgets.form.fields.TextItem#getLength
 * @see com.smartgwt.client.widgets.form.fields.TextAreaItem#getLength
 * @see com.smartgwt.client.widgets.form.ValuesManager#getDisableValidation
 * @see com.smartgwt.client.data.SimpleType#getValidators
 */
public interface Validation {
}

==> smartgwtee-eval-12.0p.zip: com/smartgwt/client/docs/Validation.java <==

package com.smartgwt.client.docs;

/**
 * Validation
 * @see com.smartgwt.client.types.CharacterCasing
 * @see com.smartgwt.client.widgets.form.validator.Validator#addValidator
 * @see com.smartgwt.client.widgets.form.validator.Validator#addValidators
 * @see com.smartgwt.client.widgets.form.validator.Validator#addValidatorDefinition
 * @see com.smartgwt.client.widgets.form.validator.Validator#addValidatorDefinitions
 * @see com.smartgwt.client.widgets.form.DynamicForm#validateData
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorsHTML
 * @see com.smartgwt.client.widgets.form.DynamicForm#getItemErrorHTML
 * @see com.smartgwt.client.widgets.form.DynamicForm#validate
 * @see com.smartgwt.client.widgets.form.DynamicForm#valuesAreValid
 * @see com.smartgwt.client.widgets.form.DynamicForm#checkForValidationErrors
 * @see com.smartgwt.client.widgets.form.ValuesManager#valuesAreValid
 * @see com.smartgwt.client.widgets.form.ValuesManager#checkForValidationErrors
 * @see com.smartgwt.client.widgets.grid.ListGrid#clearRowErrors
 * @see com.smartgwt.client.data.DataSource#getUseLocalValidators
 * @see com.smartgwt.client.data.DataSourceField#getValidators
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowInlineErrors
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowErrorIcons
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowErrorText
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowErrorStyle
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorOrientation
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorItemProperties
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorItemCellStyle
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrorsPreamble
 * @see com.smartgwt.client.widgets.form.DynamicForm#getShowTitlesWithErrorMessages
 * @see com.smartgwt.client.widgets.form.DynamicForm#getErrors
 * @see com.smartgwt.client.widgets.form.DynamicForm#getValidateOnChange
 * @see com.smartgwt.client.widgets.form.DynamicForm#getUnknownErrorMessage
 * @see com.smartgwt.client.widgets.form.DynamicForm#getNoErrorDetailsMessage
 * @see com.smartgwt.client.widgets.form.DynamicForm#getValidationURL
 * @see com.smartgwt.client.widgets.form.DynamicForm#getDisableValidation
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getRequired
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getRequiredMessage
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getRequiredWhen
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowErrorIcon
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowErrorText
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getShowErrorStyle
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getErrorOrientation
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getErrorMessageWidth
 * @see com.smartgwt.client.widgets.form.fields.TextItem#getLength
 * @see com.smartgwt.client.widgets.form.fields.TextAreaItem#getLength
 * @see com.smartgwt.client.widgets.form.ValuesManager#getDisableValidation
 * @see com.smartgwt.client.data.SimpleType#getValidators
 */
public interface Validation {
}
